import { OnDestroy, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { ReplaySubject } from 'rxjs/internal/ReplaySubject';
import { NrfModelSetterService } from './model-setter.service';
import { NrfFormDirective } from '../form/form.directive';
import { NrfNestedControlContext } from './nested-control-context.class';
export { NrfNestedControlContext };
/**
 * This directive control nested inputs and sets values on the Original Model set at {@link NrfFormDirective#nrfEntity}
 *
 * #### Given an nrfEntity on the controller:
 * ```typescript
 * this.userModel = {
 *    firstName: 'John',
 *    address: {
 *        street: 'Carnaby Street'
 *    }
 * };
 * ```
 *
 * #### Use it on the form
 * ```html
 * <form [nrfEntity]="userModel">
 *   <div class="form-group">
 *      <label for="name">Name:</label>
 *
 *      <div *nrfNestedControl="'userModel.firstName'; let control=formControl">
 *        <input [formControl]="control" />
 *      </div>
 *   </div>
 * </form>
 * ```
 */
export declare class NrfNestedControlDirective implements OnInit, OnDestroy {
    private readonly modelSetter;
    private templateRef;
    private viewContainerRef;
    private nrfForm;
    /**
     * The dot notation full name of the nrfEntity
     */
    nrfModelName: string;
    ready$: ReplaySubject<{}>;
    private isRegisteredToFormGroup;
    isDestroyed: boolean;
    parentFormGroup: FormGroup;
    formControl: FormControl;
    /**
     * Used to set and get value on the entity model
     */
    modelPath: string;
    constructor(modelSetter: NrfModelSetterService, templateRef: TemplateRef<any>, viewContainerRef: ViewContainerRef, nrfForm: NrfFormDirective);
    /**
     * Register this input component to its parent form [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     *
     * And starts to emit the input's value when it changes.
     */
    ngOnInit(): void;
    ngOnDestroy(): void;
    private showViewContent();
    /**
     * Register this input to its parent [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     * to enable validations and data manipulation
     */
    private registerToFormGroup();
    /**
     * Verify if this input is inside a [NrfFormDirective]{@link NrfFormDirective}
     * and return its [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     *
     * Otherwise a new empty [FormGroup]{@link https://angular.io/api/forms/FormGroup}
     */
    private getFormGroup();
    /**
     * Verify if the [FormGroup]{@link https://angular.io/api/forms/FormGroup} has an control with the current name and return it.
     * Otherwise return a new [FormControl]{@link https://angular.io/api/forms/FormControl}
     */
    protected getFormControl(): FormControl;
    /**
     * Instantiate a new [FormControl]{@link https://angular.io/api/forms/FormControl} and return it
     */
    protected getNewFormControl(): FormControl;
    /**
     * Subscribe to [valueChanges]{@link https://angular.io/api/forms/AbstractControl#valueChanges} and update the Entity value
     */
    private subscribeToUpdateEntityValue();
    /**
     * Return the dot notation path of the Entity, without the first part,
     * because it is the Entity itself.
     */
    private getModelPathWithoutFirstPart();
    /**
     * Get the value from the [nrfEntity]{@link NrfFormDirective#nrfEntity}
     */
    private getInitialValue();
    /**
     * Set the value to the [formData]{@link NrfFormDirective#formData}
     */
    setModelValue(newValue: any): void;
    emitReadyState(): void;
}
